@@ -104,15 +104,17 @@ def apply_config(filepath, file_config, dry_run):
         gid = grp.getgrnam(file_config.group).gr_gid
 
     if not dry_run:
-        log.debug("Changing %s to uid %s gid %s", filepath, uid, gid)
-        os.chown(filepath, uid, gid)
+        if uid != -1 or gid != -1:
+            log.debug("Changing %s to uid %s gid %s", filepath, uid, gid)
+            os.chown(filepath, uid, gid)
 
         if file_config.mode is not None:
             mode = int(file_config.mode, 8)
             log.debug("Changing mode of %s to %s", filepath, file_config.mode)
             os.chmod(filepath, mode)
     else:
-        log.info("Would change %s to uid %s gid %s", filepath, uid, gid)
+        if uid != -1 or gid != -1:
+            log.info("Would change %s to uid %s gid %s", filepath, uid, gid)
 
         if file_config.mode is not None:
             log.debug("Would change mode of %s to %s", filepath, file_config.mode)
@@ -125,7 +127,7 @@ class DirectoryRender:
         self.loader = FileLoader(basedir)
         self.basedir = basedir
 
-    def render(self, destdir, inputhash, dry_run = False,
+    def render(self, destdir, inputhash, resources, dry_run = False,
             currpath = "", config = {}):
         """
         Transforms all templates and downloads all files in the directory
@@ -167,7 +169,7 @@ class DirectoryRender:
                     result[key] = config[key].atomic
 
                 apply_config(dest, get_config(stripped, config), dry_run)
-                result.update(self.render(destdir, inputhash, dry_run, relpath, config))
+                result.update(self.render(destdir, inputhash, resources, dry_run, relpath, config))
             else:
                 ext = get_sq_ext(filename)
                 if ext in extension_handles:
@@ -176,7 +178,8 @@ class DirectoryRender:
                         'inputhash':inputhash,
                         'relpath':relpath,
                         'abs_source': abs_source,
-                        'dest':dest})
+                        'dest':dest,
+                        'resources':resources})
                 else:
                     # otherwise, just copy the file
                     copyfile(abs_source, dest)
