@@ -20,6 +20,12 @@ def remove_lock_file(d, lockfile='.lock'):
     except OSError:
         pass
 
+def teardown_function(function):
+    try:
+        shutil.rmtree('/tmp/main2test/')
+    except:
+        pass
+
 test_path = os.path.join(get_test_path(), 'main_tests')
 
 def test_main_basic(tmpdir):
@@ -32,7 +38,7 @@ def test_main_basic(tmpdir):
 
     squadron_dir = os.path.join(test_path, 'main1')
 
-    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path, 'main1.config'), 'dev', None, False)
+    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path, 'main1.config'), 'dev', None, False, False)
 
     with open(os.path.join(squadron_state_dir, 'info.json')) as infojson:
         info = json.loads(infojson.read())
@@ -45,7 +51,7 @@ def test_main_basic(tmpdir):
 
     old_dir = info['dir']
 
-    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path, 'main1.config'), 'dev', None, False)
+    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path, 'main1.config'), 'dev', None, False, False)
 
     with open(os.path.join(squadron_state_dir, 'info.json')) as infojson:
         info = json.loads(infojson.read())
@@ -58,7 +64,6 @@ def test_main_basic(tmpdir):
     assert old_dir == new_dir
     remove_lock_file(info['dir'])
     assert are_dir_trees_equal(os.path.join(test_path, 'main1result'), info['dir']) == True
-    shutil.rmtree('/tmp/applytest1/')
 
 def test_main_dryrun(tmpdir):
     tmpdir = str(tmpdir)
@@ -69,7 +74,7 @@ def test_main_dryrun(tmpdir):
 
     squadron_dir = os.path.join(test_path, 'main1')
 
-    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path, 'main1.config'), 'dev', None, True)
+    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path, 'main1.config'), 'dev', None, False, True)
 
     with open(os.path.join(squadron_state_dir, 'info.json')) as infojson:
         assert "" == infojson.read()
@@ -85,7 +90,7 @@ def test_main_with_config(tmpdir):
     squadron_dir = os.path.join(test_path, 'main1')
 
     # Gets the node name from the config file
-    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path,'main1.config'), None, None, False)
+    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path,'main1.config'), None, None, False, False)
 
     with open(os.path.join(squadron_state_dir, 'info.json')) as infojson:
         info = json.loads(infojson.read())
@@ -104,7 +109,7 @@ def test_main_git(tmpdir):
 
     squadron_dir = os.path.join(test_path, 'main2')
 
-    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path,'main1.config'), 'dev', None, False)
+    main.go(squadron_dir, squadron_state_dir, os.path.join(test_path,'main1.config'), 'dev', None, False, False)
 
     with open(os.path.join(squadron_state_dir, 'info.json')) as infojson:
         info = json.loads(infojson.read())
@@ -114,7 +119,6 @@ def test_main_git(tmpdir):
     assert os.path.isdir(info['dir']) == True
     remove_lock_file(info['dir'])
     assert are_dir_trees_equal(os.path.join(test_path,'main2result'), info['dir']) == True
-    shutil.rmtree('/tmp/main2test/')
 
 def test_dont_current():
     prefix = 'test1-'
@@ -125,7 +129,14 @@ def test_dont_current():
     assert main._is_current_last(prefix, tempdir,
             os.path.join(tempdir, 'test1-1'))
 
-def test_rollback(tmpdir):
+
+@pytest.mark.parametrize("dry_run,dont_rollback", [
+    (True, False),
+    (True, True),
+    (False, False),
+    (False, True)
+])
+def test_rollback(tmpdir, dry_run, dont_rollback):
     tmpdir = str(tmpdir)
     rollback_test = os.path.join(test_path, 'rollback1')
 
@@ -146,17 +157,24 @@ def test_rollback(tmpdir):
     # Now let's get back to testing
     squadron_dir = os.path.join(rollback_test, 'squadron_dir')
 
-    with pytest.raises(squadron.exceptions.TestException) as ex:
-        makedirsp('/tmp/main2test/')
-        main.go(squadron_dir, tmpdir, os.path.join(test_path,'main1.config'), 'dev', None, False)
+    if dry_run:
+        # Should not raise
+        main.go(squadron_dir, tmpdir, os.path.join(test_path,'main1.config'), 'dev', None, dont_rollback, dry_run)
+    else:
+        # This should raise every time
+        for i in range(3):
+            with pytest.raises(squadron.exceptions.TestException) as ex:
+                makedirsp('/tmp/main2test/')
+                main.go(squadron_dir, tmpdir, os.path.join(test_path,'main1.config'), 'dev', None, dont_rollback, dry_run)
 
-    assert ex is not None
+            assert ex is not None
 
-    with open(os.path.join(tmpdir, 'info.json')) as infojson:
-        assert info == json.loads(infojson.read())
+            with open(os.path.join(tmpdir, 'info.json')) as infojson:
+                assert info == json.loads(infojson.read())
+
+            assert 'dir' in info
+            assert os.path.isdir(info['dir']) == True
+            remove_lock_file(info['dir'])
+            assert are_dir_trees_equal(old_dir, info['dir'])
+            shutil.rmtree('/tmp/main2test/')
 
-    assert 'dir' in info
-    assert os.path.isdir(info['dir']) == True
-    remove_lock_file(info['dir'])
-    assert are_dir_trees_equal(old_dir, info['dir'])
-    shutil.rmtree('/tmp/main2test/')
